import { NativeAgentOptions, NativeHttpAgentOptions, NativeHttpsAgentOptions } from './types';
/**
 * Create a keepAlive agent that will be create onces per options+target.protocol
 * Also try to gets the proxy from the http/s_proxy env variables
 * @param {string} target - The target to proxy
 * @param {NativeAgentOptions} [options]
 * @returns {HttpsAgent|HttpAgent} The agent depending on the target.
 * @example
 * const { createForeverAgent } = require('@axa/native-proxy-agent');
 * const got = require('got');
 *
 * got('http://myhost.com', { agent : createForeverAgent('http://myhost.com', {cert: 'mycert'}) });
 *
 * // This request will use same agent as they share options and protocol
 * got('http://otherhost.com', { agent : createForeverAgent('http://otherhost.com', {cert: 'mycert'}) });
 */
export declare function createForeverAgent(target: string, options?: Omit<NativeAgentOptions, 'keepAlive'>): any;
/**
 * Create a keepAlive agent that will be create onces per options+http protocol
 * Also try to gets the proxy from the http/s_proxy env variables
 * @param {NativeAgentOptions} [options]
 * @returns {HttpAgent} The agent depending on the target.
 * @example
 * const { createHttpForeverAgent } = require('@axa/native-proxy-agent');
 * const got = require('got');
 *
 * got('http://myhost.com', { agent : createHttpForeverAgent({cert: 'mycert'}) });
 *
 * // This request will use same agent as they share options and protocol
 * got('http://otherhost.com', { agent : createHttpForeverAgent({cert: 'mycert'}) });
 */
export declare function createHttpForeverAgent(options?: Omit<NativeHttpAgentOptions, 'keepAlive'>): any;
/**
 * Create a keepAlive agent that will be create onces per options+https protocol
 * Also try to gets the proxy from the http/s_proxy env variables
 * @param {NativeAgentOptions} [options]
 * @returns {HttpAgent} The agent depending on the target.
 * @example
 * const { createHttpForeverAgent } = require('@axa/native-proxy-agent');
 * const got = require('got');
 *
 * got('https://myhost.com', { agent : createHttpsForeverAgent({cert: 'mycert'}) });
 *
 * // This request will use same agent as they share options and protocol
 * got('https://otherhost.com', { agent : createHttpsForeverAgent({cert: 'mycert'}) });
 */
export declare function createHttpsForeverAgent(options?: Omit<NativeHttpsAgentOptions, 'keepAlive'>): any;
//# sourceMappingURL=forever-agent.d.ts.map