"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpsAgent = void 0;
/*
 * Copyright (c) AXA Group Operations Spain S.A.
 *
 * Licensed under the AXA Group Operations Spain S.A. License (the "License");
 * you may not use this file except in compliance with the License.
 * A copy of the License can be found in the LICENSE.TXT file distributed
 * together with this file.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
const https = __importStar(require("https"));
const hyperid_1 = __importDefault(require("hyperid"));
const net = __importStar(require("net"));
const tls = __importStar(require("tls"));
const utils_1 = require("./utils");
class HttpsAgent extends https.Agent {
    constructor(options) {
        super(options);
        this.name = options.name || (0, hyperid_1.default)(true)();
    }
    createConnectionHttpsAfterHttp(options, cb) {
        let socket;
        if (options.proxy.protocol === 'https') {
            socket = tls.connect(options.proxy);
        }
        else {
            socket = net.connect(options.proxy);
            if (options.keepAlive === true) {
                socket.setKeepAlive(true);
            }
        }
        const onError = (error) => {
            socket.destroy();
            cb(error);
        };
        const onData = (data) => {
            socket.removeListener('error', onError);
            const m = data.toString().match(/^HTTP\/1.1 (\d*)/);
            if (m && m[1] !== '200') {
                socket.destroy();
                return cb(new Error(m[0]));
            }
            Object.assign(options, { socket });
            // @ts-ignore, because of a bug on Agent @types https://github.com/DefinitelyTyped/DefinitelyTyped/issues/16735@types
            return cb(null, super.createConnection(options));
        };
        socket.once('error', onError);
        socket.once('data', onData);
        let msg = `CONNECT ${options.hostname}:${options.port} HTTP/1.1\r\n`;
        if (options.proxy.auth) {
            const auth = Buffer.from(options.proxy.auth).toString('base64');
            msg += `Proxy-Authorization: Basic ${auth}\r\n`;
        }
        if (options.proxy.headers) {
            Object.keys(options.proxy.headers).forEach(header => {
                msg += `${header}: ${options.proxy.headers[header]}\r\n`;
            });
        }
        msg += `Host: ${options.hostname}:${options.port} \r\n`;
        msg += '\r\n';
        socket.write(msg);
    }
    createConnection(options, cb) {
        if (options.proxy && (0, utils_1.requestShouldUseProxy)(options)) {
            this.createConnectionHttpsAfterHttp(options, cb);
        }
        else {
            // @ts-ignore, because of a bug on Agent @types https://github.com/DefinitelyTyped/DefinitelyTyped/issues/16735@types
            cb(null, super.createConnection(options));
        }
    }
}
exports.HttpsAgent = HttpsAgent;
exports.default = HttpsAgent;
//# sourceMappingURL=https-agent.js.map